@@ -24,7 +24,8 @@
  * @author Christian Grothoff
  * @author Dennis Neufeld
  */
-#include <gnunet/platform.h>
+#define _GNU_SOURCE
+#include <stdio.h>
 #include <gnunet/gnunet_util_lib.h>
 #include "anastasis-gtk_helper.h"
 #include <jansson.h>
